<?php

namespace App\Wrangler\Components;

use Illuminate\Http\Request;
use Medialight\Textstem\Helpers\MediaAsset;
use Medialight\Textstem\Models\WranglerPage;
use Medialight\Textstem\Wrangler\ActiveComponent;

class Banner extends ActiveComponent
{
    public static string $description = 'Banners, with images and (optional) text';
    public static string $version = '1.0.1';

    public $config;

    public array $editSetup = [
        [
            'name' => 'template',
            'controltype' => 'select-template',
            'value' => 'default',

        ],
        [
            'name' => 'title',
            'controltype' => 'text',
            'value' => '',
            'label' => 'Title',
        ],
        [
            'name' => 'strapline',
            'controltype' => 'text',
            'value' => '',
            'label' => 'SubTitle / Strapline',
        ],
        [
            'name' => 'body',
            'controltype' => 'textarea',
            'value' => '',
            'label' => 'Content',
        ],
        [
            'name' => 'content',
            'controltype' => 'image',
            'value' => '',
            'label' => "Image (Desktop)",
            'aspect' => '16/6',
            'size' =>3
        ],
        [
            'name' => 'contentmobile',
            'controltype' => 'image',
            'value' => '',
            'label' => "Image (Mobile)",
            'aspect' => 'square',
            'size' =>1
        ],
        [
            'name' => 'link',
            'controltype' => 'page_selector',
            'value' => '',
            'label' => 'Link',
        ],
        [
            'name' => 'label_placement',
            'controltype' => 'select',
            'value' => 'bottom-left',
            'options' => [
                'top-left' => 'Top Left',
                'top-right' => 'Top Right',
                'bottom-left' => 'Bottom Left',
                'bottom-right' => 'Bottom Right',
                'center' => 'Center',

            ],
            'label' => 'Label Placement',
            'size' => 1
        ],
        [
            'name' => 'bgColor',
            'controltype' => 'color',
            'value' => '#000000',
            'label' => 'Background Colour',
            'size' => 1
        ],
        [
            'name' => 'textColor',
            'controltype' => 'color',
            'value' => '#ffffff',
            'label' => 'Text Colour',
            'size' => 1
        ],
        [
            'name' => 'blend',
            'controltype' => 'select',
            'options' => [
                'none' => '',
                'darken' => 'darken',
                'screen' => 'screen',
                'overlay' => 'overlay',
                'multiply' => 'multiply',
                'lighten' => 'lighten',
                'color-dodge' => 'color-dodge',
                'color-burn' => 'color-burn',

            ],
            'value' => '',
            'label' => 'Effect',
            'size' => 1
        ],

    ];

    public function __construct($instance)
    {
        parent::__construct($instance);
        $this->config['asset'] = MediaAsset::loadForPath($this->config['content'] ?? '');
        $this->config['assetmobile'] = MediaAsset::loadForPath($this->config['contentmobile'] ?? ($this->config['content'] ?? ''));
    }
    public function render(Request $request, WranglerPage $wranglerPage)
    {
        $view = $this->getView();
        return view($view, $this->data())->render();
    }

    public function preview()
    {
        //return '<div class="border bg-black text-white"><img src="'. \Storage::url($this->config['content'] ?? '').'" /></div>';
        $view = 'wrangler.components.banner.default';
        return view($view, $this->data())->render();
    }
}
